summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmlatheedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmlatheedit.h')
-rw-r--r--kpovmodeler/pmlatheedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmlatheedit.h b/kpovmodeler/pmlatheedit.h
index c33a9711..83a0a4ec 100644
--- a/kpovmodeler/pmlatheedit.h
+++ b/kpovmodeler/pmlatheedit.h
@@ -47,9 +47,9 @@ class PMLatheEdit : public PMSolidObjectEdit
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMLatheEdit with tqparent and name
*/
- PMLatheEdit( TQWidget* tqparent, const char* name = 0 );
+ PMLatheEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -47,9 +47,9 @@ class PMLatheEdit : public PMSolidObjectEdit
public:
/**
- * Creates a PMLatheEdit with tqparent and name
+ * Creates a PMLatheEdit with parent and name
*/